const os = require('os');
const fs = require('fs');
const path = require('path');
const child_exec = require('child_process').execSync;
const chalk = require('chalk');
const pkg = require('../package.json');

const fleFile = path.join(os.homedir(), '.fle.json');
const date = (function () {
  let d = new Date();
  let year = d.getFullYear();
  let month = d.getMonth() + 1;
  let day = d.getDate();
  return [year, month > 9 ? month : '0' + month, day > 9 ? day : '0' + day].join('-');
})();

function check () {
  const str = child_exec('npm view ' + pkg.name).toString();
  const matched = str.match(/\'dist-tags\': \{ latest: \'([\d\.]+)\' \}/);

  if (matched && matched[1]) {
    return matched[1] > pkg.version;
  }

  return false;
}

function dailyUpgrade () {
  if (!fs.existsSync(fleFile) || require(fleFile).date !== date) {
    upgrade();
  }
}

function upgrade (showInfo) {
  if (check()) {
    console.log('');
    console.log(chalk.green('--------- Update starting... -----------'));
    console.log('');
    child_exec('npm install -g ' + pkg.name, { stdio: 'inherit' });
    console.log('');
    console.log(chalk.green('--------- Update successfully! ---------'));
    console.log('');
  } else if (showInfo) {
    console.log('\n' + chalk.cyan('It\'s already the lastest version.') + '\n');
  }

  fs.writeFileSync(fleFile, JSON.stringify({ date }, null, 2));
}

exports.check = check;
exports.dailyUpgrade = dailyUpgrade;
exports.upgrade = upgrade;
